# coding: utf-8

# flake8: noqa
"""
    AI Decision Protocol

    AI Decision Protocol Specification

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from aitp.stubs.models.decision import Decision
from aitp.stubs.models.decision_decision import DecisionDecision
from aitp.stubs.models.decision_option import DecisionOption
from aitp.stubs.models.decision_option_variant import DecisionOptionVariant
from aitp.stubs.models.decision_protocol import DecisionProtocol
from aitp.stubs.models.payment_plan import PaymentPlan
from aitp.stubs.models.quote import Quote
from aitp.stubs.models.request_decision import RequestDecision
from aitp.stubs.models.request_decision_request_decision import RequestDecisionRequestDecision
from aitp.stubs.models.selected_option import SelectedOption



# coding: utf-8

"""
    AI Decision Protocol

    AI Decision Protocol Specification

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from aitp.stubs.models.request_decision_request_decision import RequestDecisionRequestDecision

class RequestDecision(BaseModel):
    """
    RequestDecision
    """
    var_schema: StrictStr = Field(default=..., alias="$schema")
    request_decision: RequestDecisionRequestDecision = Field(...)
    additional_properties: Dict[str, Any] = {}
    __properties = ["$schema", "request_decision"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RequestDecision:
        """Create an instance of RequestDecision from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of request_decision
        if self.request_decision:
            _dict['request_decision'] = self.request_decision.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RequestDecision:
        """Create an instance of RequestDecision from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RequestDecision.parse_obj(obj)

        _obj = RequestDecision.parse_obj({
            "var_schema": obj.get("$schema"),
            "request_decision": RequestDecisionRequestDecision.from_dict(obj.get("request_decision")) if obj.get("request_decision") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    AI Decision Protocol

    AI Decision Protocol Specification

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist, validator
from aitp.stubs.models.decision_option import DecisionOption

class RequestDecisionRequestDecision(BaseModel):
    """
    RequestDecisionRequestDecision
    """
    id: StrictStr = Field(...)
    title: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    type: Optional[StrictStr] = 'radio'
    options: conlist(DecisionOption, min_items=1) = Field(...)
    additional_properties: Dict[str, Any] = {}
    __properties = ["id", "title", "description", "type", "options"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('products', 'checkbox', 'radio', 'confirmation',):
            raise ValueError("must be one of enum values ('products', 'checkbox', 'radio', 'confirmation')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RequestDecisionRequestDecision:
        """Create an instance of RequestDecisionRequestDecision from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in options (list)
        _items = []
        if self.options:
            for _item in self.options:
                if _item:
                    _items.append(_item.to_dict())
            _dict['options'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RequestDecisionRequestDecision:
        """Create an instance of RequestDecisionRequestDecision from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RequestDecisionRequestDecision.parse_obj(obj)

        _obj = RequestDecisionRequestDecision.parse_obj({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "type": obj.get("type") if obj.get("type") is not None else 'radio',
            "options": [DecisionOption.from_dict(_item) for _item in obj.get("options")] if obj.get("options") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    AI Decision Protocol

    AI Decision Protocol Specification

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictInt, StrictStr, confloat, conint, conlist
from aitp.stubs.models.decision_option_variant import DecisionOptionVariant
from aitp.stubs.models.quote import Quote

class DecisionOption(BaseModel):
    """
    DecisionOption
    """
    id: StrictStr = Field(...)
    name: Optional[StrictStr] = None
    short_variant_name: Optional[StrictStr] = None
    image_url: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    quote: Optional[Quote] = None
    reviews_count: Optional[StrictInt] = None
    five_star_rating: Optional[Union[confloat(le=5, ge=0, strict=True), conint(le=5, ge=0, strict=True)]] = None
    url: Optional[StrictStr] = None
    variants: Optional[conlist(DecisionOptionVariant)] = None
    additional_properties: Dict[str, Any] = {}
    __properties = ["id", "name", "short_variant_name", "image_url", "description", "quote", "reviews_count", "five_star_rating", "url", "variants"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DecisionOption:
        """Create an instance of DecisionOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of quote
        if self.quote:
            _dict['quote'] = self.quote.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in variants (list)
        _items = []
        if self.variants:
            for _item in self.variants:
                if _item:
                    _items.append(_item.to_dict())
            _dict['variants'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DecisionOption:
        """Create an instance of DecisionOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DecisionOption.parse_obj(obj)

        _obj = DecisionOption.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "short_variant_name": obj.get("short_variant_name"),
            "image_url": obj.get("image_url"),
            "description": obj.get("description"),
            "quote": Quote.from_dict(obj.get("quote")) if obj.get("quote") is not None else None,
            "reviews_count": obj.get("reviews_count"),
            "five_star_rating": obj.get("five_star_rating"),
            "url": obj.get("url"),
            "variants": [DecisionOptionVariant.from_dict(_item) for _item in obj.get("variants")] if obj.get("variants") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

# flake8: noqa

"""
    AI Decision Protocol

    AI Decision Protocol Specification

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package

# import ApiClient
from aitp.stubs.api_response import ApiResponse
from aitp.stubs.api_client import ApiClient
from aitp.stubs.configuration import Configuration
from aitp.stubs.exceptions import OpenApiException
from aitp.stubs.exceptions import ApiTypeError
from aitp.stubs.exceptions import ApiValueError
from aitp.stubs.exceptions import ApiKeyError
from aitp.stubs.exceptions import ApiAttributeError
from aitp.stubs.exceptions import ApiException

# import models into sdk package
from aitp.stubs.models.decision import Decision
from aitp.stubs.models.decision_decision import DecisionDecision
from aitp.stubs.models.decision_option import DecisionOption
from aitp.stubs.models.decision_option_variant import DecisionOptionVariant
from aitp.stubs.models.decision_protocol import DecisionProtocol
from aitp.stubs.models.payment_plan import PaymentPlan
from aitp.stubs.models.quote import Quote
from aitp.stubs.models.request_decision import RequestDecision
from aitp.stubs.models.request_decision_request_decision import RequestDecisionRequestDecision
from aitp.stubs.models.selected_option import SelectedOption
